@@ -1,15 +1,8 @@
-from os import environ
-
 from .casscache import Client  # NOQA
 
 from sentry.nodestore.base import NodeStorage
 from sentry.utils.cache import memoize
 
-if "SENTRY_EVENT_RETENTION_DAYS" in environ:
-    ttl = int(environ.get('SENTRY_EVENT_RETENTION_DAYS')) * 24 * 60 * 60
-else:
-    ttl = 0
-
 class CassandraNodeStorage(NodeStorage):
     """
     A Cassandra-based backend for storing node data.
@@ -49,8 +42,8 @@ class CassandraNodeStorage(NodeStorage):
     def _get_bytes_multi(self, id_list):
         return self.connection.get_multi(id_list)
 
-    def _set_bytes(self, id, data):
-        self.connection.set(id, data, ttl)
+    def _set_bytes(self, id, data, ttl=None):
+        self.connection.set(id, data)
 
     def delete(self, id):
         self.connection.delete(id)
